toddler.template


*level*clj


copyclj

(copy file target)

escape-dataclj

(escape-data data)

osclj


processclj

(process file target)
(process file target variables)

Function will take source file and target file and repace all {{variable}} with provided variable definitions.

Function will take source file and target file and
repace all {{variable}} with provided variable
definitions.
raw docstring

random-stringclj

(random-string)
(random-string length)

run-scriptclj

(run-script & lines)

cljdoc builds & hosts documentation for Clojure/Script libraries