(copy file target)(escape-data data)(process file target)(process file target variables)Function will take source file and target file and repace all {{variable}} with provided variable definitions.
Function will take source file and target file and
repace all {{variable}} with provided variable
definitions.(random-string)(random-string length)(run-script & lines)cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |