toddler.template


*level*clj


copyclj

(copy file target)

processclj

(process file target)
(process file target variables)

Function will take source file and target file and repace all {{variable}} with provided variable definitions.

Function will take source file and target file and
repace all {{variable}} with provided variable
definitions.
raw docstring

random-stringclj

(random-string)
(random-string length)

cljdoc builds & hosts documentation for Clojure/Script libraries